<?php

namespace Drupal\copysafe_video_protection\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure Copysafe Video settings for this site.
 *
 * @internal
 */
class CopySafeVideoSettings extends ConfigFormBase {

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Constructs a Copysafe Video settings object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->configFactory = $config_factory;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['copysafe_video_protection.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'copysafe_video_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // Retrieve the copysafe_video_protection.settings configuration

    $settings = $this->config('copysafe_video_protection.settings');
    $help_image_path='/modules/contrib/copysafe_video_protection/images/help-24-30.png';
    $form['default_sessings'] = array(
        '#type' => 'fieldset',
        '#title' => t('Default settings applied to all video pages:'),
        '#group' => 'default'
    );
    $form['default_sessings']['admin_only'] = [
        '#title' => $this->t('<img src="'.$help_image_path.'"> Allow Admin Only'),
        '#type' => 'checkbox',
        '#default_value' => !empty($settings->get('admin_only')) ? $settings->get('admin_only') : 0,
    ];
    $form['default_sessings']['uploadfolder'] = [
        '#type' => 'textfield',
        '#default_value' => !empty($settings->get('uploadfolder')) ? $settings->get('uploadfolder') : 'upload_folder/copysafe_video_protection',
        '#title' => $this->t('<img src="'.$help_image_path.'"> Upload Folder'),
        '#required' => TRUE,
    ];

    $form['default_sessings']['mode'] = [
        '#type' => 'select',
        '#default_value' => !empty($settings->get('mode')) ? $settings->get('mode') : array('licensed'),
        '#options' => [
            'demo' => $this->t('Demo Mode'),
            'licensed' => $this->t('Licensed'),
            'debug' => $this->t('Debugging Mode'),
        ],
        '#title' => $this->t('<img src="'.$help_image_path.'"> Mode'),
    ];

    $options = [
        'asps' => $this->t('Allow ArtisBrowser'),
        'firefox' => $this->t('Allow Firefox (for test only)'),
        'chrome' => $this->t('Allow Chrome (for test only)'),
    ];

    $form['default_sessings']['artisbrowser_min_version'] = [
        '#type' => 'textfield',
        '#default_value' => !empty($settings->get('artisbrowser_min_version')) ? $settings->get('artisbrowser_min_version') : '30.0',
        '#title' => $this->t('<img src="'.$help_image_path.'"> Minimum Version'),
    ];
    $form['default_sessings']['width'] = [
        '#type' => 'textfield',
        '#default_value' => !empty($settings->get('width')) ? $settings->get('width') : '620',
        '#title' => $this->t('<img src="'.$help_image_path.'"> Width - in pixels:'),
    ];
    $form['default_sessings']['height'] = [
        '#type' => 'textfield',
        '#default_value' => !empty($settings->get('height')) ? $settings->get('height') : '400',
        '#title' => $this->t('<img src="'.$help_image_path.'">  Height - in pixels:'),
    ];
    $form['default_sessings']['allow_remote'] = [
        '#title' => $this->t('<img src="'.$help_image_path.'">  AllowRemote'),
        '#type' => 'checkbox',
        '#default_value' => !empty($settings->get('allow_remote')) ? $settings->get('allow_remote') : TRUE,
    ];

    $form['browser_sessings'] = array(
        '#type' => 'fieldset',
        '#title' => t('Browser allowed'),
        '#group' => 'browser'
    );


    $form['browser_sessings']['browser'] = [
        '#title' => $this->t('<img src="'.$help_image_path.'">  Select Browsers'),
        '#type' => 'checkboxes',
        '#default_value' => !empty($settings->get('browser')) ? $settings->get('browser') : array('asps'),
        '#options' => $options,
    ];
    $form['watermark_sessings'] = array(
        '#type' => 'fieldset',
        '#title' => t('Watermark settings'),
        '#group' => 'browser'
    );
    $form['watermark_sessings']['watermark'] = [
        '#type' => 'select',
        '#default_value' => !empty($settings->get('watermark')) ? $settings->get('watermark') : 0,
        '#options' => [
            '0' => $this->t('Off'),
            '1' => $this->t('On'),
        ],
        '#title' => $this->t('<img src="'.$help_image_path.'"> Enabled'),
    ];

    $form['watermark_sessings']['fontsize'] = [
        '#type' => 'select',
        '#default_value' => !empty($settings->get('fontsize')) ? $settings->get('fontsize') : '',
        '#options' => [
            '10' => $this->t('10'),
            '15' => $this->t('15'),
            '20' => $this->t('20'),
            '25' => $this->t('25'),
            '30' => $this->t('30'),
            '35' => $this->t('35'),
            '40' => $this->t('40'),
        ],
        '#title' => $this->t('<img src="'.$help_image_path.'"> Text Size'),
    ];

    $form['watermark_sessings']['Color'] = [
        '#type' => 'select',
        '#default_value' => !empty($settings->get('Color')) ? $settings->get('Color') : 'FFFFFF',
        '#options' => [
            'FFFFFF' => $this->t('White'),
            'FF3333' => $this->t('Red'),
            'FFFF00' => $this->t('Yellow'),
            '00FF00' => $this->t('Green'),
            '00FFFF' => $this->t('Blue'),
        ],
        '#title' => $this->t('<img src="'.$help_image_path.'"> Text Color'),
    ];

    $form['watermark_sessings']['Position'] = [
        '#type' => 'select',
        '#default_value' => !empty($settings->get('Position')) ? $settings->get('Position') : 0,
        '#options' => [
            '0' => $this->t('Center'),
            '1' => $this->t('Bottom'),
            '2' => $this->t('Top'),
            '3' => $this->t('TopLeft'),
            '4' => $this->t('TopRight'),
            '5' => $this->t('BottomLeft'),
            '6' => $this->t('BottomRight'),
        ],
        '#title' => $this->t('<img src="'.$help_image_path.'"> Position'),
    ];

    $form['watermark_sessings']['Transparency'] = [
        '#type' => 'select',
        '#default_value' => !empty($settings->get('Transparency')) ? $settings->get('Transparency') : 9,
        '#options' => [
            '9' => $this->t('100% (opaque)'),
            '8' => $this->t('90%'),
            '7' => $this->t('80%'),
            '6' => $this->t('70%'),
            '5' => $this->t('60%'),
            '4' => $this->t('50%'),
            '3' => $this->t('40%'),
            '2' => $this->t('30%'),
            '1' => $this->t('20%'),
            '0' => $this->t('10%'),
        ],
        '#title' => $this->t('<img src="'.$help_image_path.'"> Opacity'),
    ];
    $form['#attached']['library'][] = 'copysafe_video_protection/copysafe_video_protection_style';
    
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
    $min_version = $form_state->getValue('artisbrowser_min_version');
    $min_version_parts = explode('.', $min_version);
    if (count($min_version_parts) > 2|| !is_numeric($min_version_parts[0]) || !is_numeric($min_version_parts[1])) {
      $form_state->setErrorByName('artisbrowser_min_version', $this->t('The ArtisBrowser minimum version should be a valid version number with 2 parts like 30.0!'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('copysafe_video_protection.settings')
      ->set('admin_only', $form_state->getValue('admin_only'))
      ->set('uploadfolder', $form_state->getValue('uploadfolder'))
      ->set('mode', $form_state->getValue('mode'))
      ->set('browser', $form_state->getValue('browser'))
      ->set('artisbrowser_min_version', $form_state->getValue('artisbrowser_min_version'))
      ->set('width', $form_state->getValue('width'))
      ->set('height', $form_state->getValue('height'))
      ->set('allow_remote', $form_state->getValue('allow_remote'))
      ->set('watermark', $form_state->getValue('watermark'))
      ->set('fontsize', $form_state->getValue('fontsize'))
      ->set('Color', $form_state->getValue('Color'))
      ->set('Position', $form_state->getValue('Position'))
      ->set('Transparency', $form_state->getValue('Transparency'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
